summaryrefslogtreecommitdiffstats
path: root/src/privsep.c
diff options
context:
space:
mode:
authorRoy Marples <roy@marples.name>2021-02-02 17:09:25 +0000
committerRoy Marples <roy@marples.name>2021-02-02 17:09:25 +0000
commitdef6e99252c1d3c549a37543b1914b0b8a342851 (patch)
tree11bc57efa44a2a4264ecd6a2f0922b6ec8d971f6 /src/privsep.c
parentf6082bca98c2d16492d56e98ec9ea927c36c248a (diff)
downloaddhcpcd-def6e99252c1d3c549a37543b1914b0b8a342851.tar.xz
Rename Privileged Actioneer to Privileged Proxy
Sadly actioneer is not a real word.
Diffstat (limited to 'src/privsep.c')
-rw-r--r--src/privsep.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/privsep.c b/src/privsep.c
index b63a9d4b..0a9f93bf 100644
--- a/src/privsep.c
+++ b/src/privsep.c
@@ -33,7 +33,7 @@
* or address specific listener.
* Spawn an unpriv process to send/receive common network data.
* Then drop all privs and start running.
* Every process aside from the privileged actioneer is chrooted.
* All privsep processes ignore signals - only the manager process accepts them.
*
* dhcpcd will maintain the config file in the chroot, no need to handle
@@ -470,7 +470,7 @@ ps_start(struct dhcpcd_ctx *ctx)
case 0:
return 0;
default:
- logdebugx("spawned privileged actioneer on PID %d", pid);
+ logdebugx("spawned privileged proxy on PID %d", pid);
}
/* No point in spawning the generic network listener if we're
@@ -611,7 +611,7 @@ ps_stop(struct dhcpcd_ctx *ctx)
ret = r;
/* We've been chrooted, so we need to tell the
* privileged actioneer to remove the pidfile. */
if (ps_root_unlink(ctx, ctx->pidfile) == -1)
ret = -1;
@@ -33,7 +33,7 @@
* Spawn an unpriv process to send/receive common network data.
* Then drop all privs and start running.
- * Every process aside from the privileged actioneer is chrooted.
+ * Every process aside from the privileged proxy is chrooted.
* All privsep processes ignore signals - only the manager process accepts them.
*
@@ -611,7 +611,7 @@ ps_stop(struct dhcpcd_ctx *ctx)
ret = r;
/* We've been chrooted, so we need to tell the
- * privileged actioneer to remove the pidfile. */
+ * privileged proxy to remove the pidfile. */
if (ps_root_unlink(ctx, ctx->pidfile) == -1)
ret = -1;